@@ -1,9 +1,12 @@
-use strict;
+# The "experimental" below is not actually scary.  The feature went on to be
+# de-experimental-ized with no changes and is now on by default in perl v5.24
+# and later. -- rjbs, 2021-03-14
+use 5.020;
 use warnings;
-use 5.024;
+use experimental qw(postderef postderef_qq);
 
 package App::Cmd;
-$App::Cmd::VERSION = '0.332';
+$App::Cmd::VERSION = '0.333';
 use parent 'App::Cmd::ArgProcessor';
 # ABSTRACT: write command line apps with less suffering
 
@@ -744,7 +747,7 @@ App::Cmd - write command line apps with less suffering
 
 =head1 VERSION
 
-version 0.332
+version 0.333
 
 =head1 SYNOPSIS
 
