@@ -1,7 +1,12 @@
-use strict;
+# The "experimental" below is not actually scary.  The feature went on to be
+# de-experimental-ized with no changes and is now on by default in perl v5.24
+# and later. -- rjbs, 2021-03-14
+use 5.020;
 use warnings;
+use experimental qw(postderef postderef_qq);
+
 package App::Cmd::Setup;
-$App::Cmd::Setup::VERSION = '0.332';
+$App::Cmd::Setup::VERSION = '0.333';
 # ABSTRACT: helper for setting up App::Cmd classes
 
 #pod =head1 OVERVIEW
@@ -214,7 +219,7 @@ App::Cmd::Setup - helper for setting up App::Cmd classes
 
 =head1 VERSION
 
-version 0.332
+version 0.333
 
 =head1 OVERVIEW
 
